"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Any, Dict, List
from typing_extensions import Annotated, TypedDict


class UpsertDocsRequestBodyTypedDict(TypedDict):
    docs: List[Dict[str, Any]]
    r"""A list of documents to upsert."""


class UpsertDocsRequestBody(BaseModel):
    docs: List[Dict[str, Any]]
    r"""A list of documents to upsert."""


class UpsertDocsRequestTypedDict(TypedDict):
    collection_name: str
    r"""Collection name."""
    request_body: UpsertDocsRequestBodyTypedDict


class UpsertDocsRequest(BaseModel):
    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        UpsertDocsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
